FAST-OAD notebooks
==================

This folder contains two sets of notebook tutorials to help the user get more familiar with FAST-OAD.

[01) Quick start](01_Quick_start/beam_problem.ipynb)
-----------------

This tutorial presents how to manage and solve a problem using FAST-OAD. It introduces the specifics of FAST-OAD compared to OpenMDAO and explains the module registration mechanic. It is best suited for user already familiar with Python and with a basic knowledge of the features of the OpenMDAO framework.

[02) From Python to FAST-OAD](02_From_Python_to_FAST-OAD/01_summary.ipynb)
-----------------

The aim of this set of tutorials is to gradually introduce the user to the solving of a multidisciplinary problem using OpenMDAO and FAST-OAD. The same aircraft sizing problem is presented under different formats - from very basic Python to FAST-OAD syntax - and the pros and cons are highlighted along the way. It is aimed at starting users.

> **Note**
> 
> Both tutorials contain the same level of informations on the specifics of FAST-OAD. The first tutorial, however, is meant for a direct introduction of the features of the framework. The second one, on the other hand, is better suited for a step-by-step introduction to the features of OpenMDAO and FAST-OAD.